@@ -1,4 +1,4 @@
-__version__ = '2.2.4'
+__version__ = '2.3.0'
 
 from .account import *
 from .aes import *
@@ -9,6 +9,8 @@ from .creator_code import *
 from .endpoints import *
 from .enums import *
 from .errors import *
+from .map import *
 from .news import *
+from .playlist import *
 from .shop import *
 from .stats import *
